#
# spec file for package netdata
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define netdata_user    netdata
%define netdata_group   netdata
%if 0%{?suse_version} > 1220
%bcond_without systemd
%else
%bcond_with    systemd
%endif
Name:           netdata
Version:        1.10.0
Release:        lp152.3.7
Summary:        A system for distributed real-time performance and health monitoring
# netdata is GPL-3.0+ other licenses refer to included third-party software (see LICENSE.md)
License:        GPL-3.0-or-later AND MIT AND BSD-2-Clause AND BSD-3-Clause AND LGPL-2.1-only AND OFL-1.1 AND CC0-1.0
Group:          System/Monitoring
Url:            http://my-netdata.io/
Source0:        https://github.com/firehol/netdata/releases/download/v%{version}/netdata-%{version}.tar.xz
Source1:        https://github.com/firehol/netdata/releases/download/v%{version}/netdata-%{version}.tar.xz.asc
Source2:        netdata.keyring
Source3:        netdata-rpmlintrc
Patch0:         netdata-logrotate-su.patch
Patch1:         netdata-automake-no-dist-xz.patch
Patch2:         netdata-smartd-log-path.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  libcap-devel
BuildRequires:  libmnl-devel
BuildRequires:  libuuid-devel
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  zlib-devel
Requires(pre):  shadow
Recommends:     PyYAML
Recommends:     curl
Recommends:     iproute-tc
Recommends:     lm_sensors
Recommends:     nmap-ncat
Recommends:     python
Recommends:     python2-PyMySQL
Recommends:     python2-psycopg2
Suggests:       logrotate
Suggests:       nodejs
%if 0%{?suse_version} > 1140
%ifarch i586 x86_64
BuildRequires:  freeipmi-devel
%endif
%endif
%if 0%{?sle_version} >= 130000
BuildRequires:  libnetfilter_acct-devel
%endif

%description
netdata is a system for distributed real-time performance and health monitoring.
It provides insights, in real-time, of everything happening on the system it
runs on (including applications such as web and database servers),
using interactive web dashboards.

%prep
%setup -q
%patch0
%patch1 -p1
%patch2 -p1
dos2unix web/lib/tableExport-1.6.0.min.js
sed -i 's,^#!%{_bindir}/env bash,#!/bin/bash,' plugins.d/* python.d/*.sh

%build
autoreconf -fi
%configure \
	--docdir="%{_docdir}/%{name}-%{version}" \
%if 0%{?sle_version} >= 130000
	--enable-plugin-nfacct \
%endif
	--with-zlib \
	--with-math \
	--with-user=%{netdata_user} \
	%{?conf}
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -name .keep -delete
install -D -m 0644 system/%{name}.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
install -D -m 0644 system/%{name}.conf %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf

%if %{with systemd}
install -D -m 0644 system/%{name}.service %{buildroot}%{_unitdir}/%{name}.service
ln -s -f %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
%else
%if 0%{?sle_version} >= 120000
install -D -m 0755 system/%{name}-init-d %{buildroot}%{_sysconfdir}/init.d/%{name}
%else
install -D -m 0755 system/%{name}-lsb %{buildroot}%{_sysconfdir}/init.d/%{name}
%endif
ln -s -f %{_sysconfdir}/init.d/%{name} %{buildroot}%{_sbindir}/rc%{name}
%endif

%fdupes -s %{buildroot}

%pre
getent group %{netdata_group} >/dev/null || \
	%{_sbindir}/groupadd -r %{netdata_group}
getent passwd %{netdata_user} >/dev/null || \
	%{_sbindir}/useradd -r -g %{netdata_group} -s /bin/false \
	-c "netdata daemon user" -d %{_localstatedir}/lib/empty %{netdata_user}
%{_sbindir}/usermod -g %{netdata_group} %{netdata_user} >/dev/null
%if %{with systemd}
%service_add_pre %{name}.service
%endif

%post
%if %{with systemd}
%service_add_post %{name}.service
%else
%fillup_and_insserv %{name}
%endif

%preun
%if %{with systemd}
%service_del_preun %{name}.service
%else
%stop_on_removal %{name}
%endif

%postun
%if %{with systemd}
%service_del_postun %{name}.service
%else
%restart_on_update %{name}
%insserv_cleanup
%endif

%files
%doc ChangeLog README.md
%if 0%{?sle_version} <= 130000
%doc LICENSE.md COPYING
%else
%license LICENSE.md COPYING
%endif

%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/charts.d
%dir %{_sysconfdir}/%{name}/node.d
%config(noreplace) %{_sysconfdir}/%{name}/*.conf
%config(noreplace) %{_sysconfdir}/%{name}/charts.d/*.conf
%config(noreplace) %{_sysconfdir}/%{name}/health.d/*.conf
%config(noreplace) %{_sysconfdir}/%{name}/python.d/*.conf
%config(noreplace) %{_sysconfdir}/%{name}/statsd.d/*.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}

%{_sysconfdir}/%{name}/node.d/*.md

%{_libexecdir}/%{name}

%{_sbindir}/%{name}
%{_sbindir}/rc%{name}

%attr(0750,%{netdata_user},root) %dir %{_localstatedir}/cache/%{name}
%attr(0750,%{netdata_user},root) %dir %{_localstatedir}/log/%{name}
%attr(0750,%{netdata_user},root) %dir %{_localstatedir}/lib/%{name}

%attr(-,root,%{netdata_group}) %dir %{_datadir}/%{name}
%dir %{_sysconfdir}/%{name}/health.d
%dir %{_sysconfdir}/%{name}/python.d
%dir %{_sysconfdir}/%{name}/statsd.d

%if %{with systemd}
%{_unitdir}/%{name}.service
%else
%{_sysconfdir}/init.d/%{name}
%endif

%defattr(0644,root,%{netdata_group},0755)
%{_datadir}/%{name}/web

%changelog
* Tue Mar 27 2018 9+suse@cirno.systems
- Remove _service
- Add GPG signature
- Use %%license macro
- Update to v1.10.0
  * new plugins:
  - BTRFS - monitor the allocations of BTRFS filesystems (netdata can now
    properly detect when btrfs is going out of space)
  - BCACHE - monitor the caching block layer that allows building hybrid
    disks using normal HDDs and SSDs
  - Ceph - monitor ceph distributed storage
  - nginx plus - monitor the nginx+ web servers
  - libreswan - monitor IPSEC tunnels
  - Traefik - monitor traefik reverse proxies
  - icecast - monitor icecast streaming servers
  - ntpd - monitor NTP servers
  - httpcheck - monitor any remote web server
  - portcheck - monitor any remote TCP port
  - spring-boot - monitor java spring boot applications
  - dnsdist - monitor dnsdist name servers
  - hugepages - monitor the allocation of Linux hugepages
  * enhanced/improved plugins:
  - statsd
    + statsd dimensions now support the options the external plugin
    dimensions support (currently the only usable option is hidden to add
    the dimension, but make it hidden on the dashboard - a hidden
    dimension can participate in various calculations, including alarms).
    + statsd now reports the CPU usage of its threads at the netdata
    section.
    + statsd metrics are logged to access.log the first time they are
    encountered.
    + statsd metrics now accept the special value zinit to allow them get
    initialized without altering their values (this is useful if you have
    rare metrics that you need to initialize when netdata starts).
    + statsd over TCP is now a lot faster - netdata can process up to 3.5mil
    statsd metrics / second using just one core. Added options to control
    the timeouts of TCP statsd connections.
    + fixed the title and context of statsd private charts
    + statsd private charts can now be hidden from the dashboard
  - web_log
    + Added web server response timings histogram
  - containers monitoring
    + netdata now monitors systemd-nspawn containers.
    + netdata now renames charts of kubernetes containers.
    + virsh is now called with -r to avoid prompting for password
    + cgroup-network is now a lot more strict, preventing unauthorized
    privilege escalation
    + cgroup-network now searches for container processes in sub-cgroups
    too - this improves the mapping of network interfaces to containers
    + cgroup-network now works even when there are no veth interfaces
    in the system
  - system memory
    + treat slab memory as cached
    + added a new chart for monitoring the memory available for use,
    before hitting swap
    + netdata now monitors Linux hugepages and (transparent) hugepages
  - diskspace
    + support huge amounts of mountpoints - netdata was crashing with stack
    overflow due to recursion - now it is a loop, so any number of mount
    points is supported
  - network interfaces
    + moved tcp passive and active opens to a separate chart, to allow the
    TCP issues dimensions scale better by default
    + updated the information presented on TCP charts to match the latest
    v4.15 kernel source
  - postgres
    + new charts:
    checkpointer
    bgwriter
    autovacuum
    replication delta
    WAL archive
    WAL
    temporary files
    + The postgres plugin now also works when postgres is in recovery mode.
  - rabbitmq
    + added Erlang run queue chart. This is useful in conjunction with the
    existing Erlang processes chart to get a better overall idea of what's
    going on in the Erlang VM.
    + added rabbitmq information on the dashboard to complement the charts.
  - apps.plugin
    netdata prior to this version was detecting the user and group of
    processes by examining the ownership of /proc/PID/stat. Unfortunately it
    seems that the owneship of files in /proc do not change when the process
    switches user. So, netdata could not detect the user and group of
    processes that started as root and then switched to another user.
    Now netdata reads /proc/PID/status:
    + process ownship information is now accurate
    + eliminated the need to read /proc/PID/statm (all the information of
    /proc/PID/statm is available in /proc/PID/status)
    + allowed netdata to read VmSwap, so a new chart has been added to
    monitor the swap memory usage per process, user and group.
    + The new plugin is 20%% more expensive in terms of CPU. We tried hard
    to optimize it, but this is as good as it can get.
  - haproxy
    + hrsp_1xx, hrsp_2xx, hrsp_3xx, hrsp_4xx, hrsp_5xx, hrsp_other,
    hrsp_total for backands and frontends
    + qtime, ctime, rtime, ttime metrics for backend servers
    + backend servers In UP state
  - uptime
    + netdata now uses /proc/uptime when CLOCK_BOOTTIME does not report the
    same uptime. In containers CLOCK_BOOTTIME reports the uptime of the
    host, while /proc/uptime reports the uptime of the container, so now
    netdata correctly reports the uptime of the container.
  - ksm
    + removed to_scan dimension
    + the savings %% reported by netdata was less than the actual - fixed it.
  - mdstat
    + various fixes to better monitor rebuild time and rate
  - elasticsearch
    + Added several charts for translog / indices segments statistics and
    JVM buffer pool utilization, which are often helpful when evaluating
    an elasticsearch node health
  - apcupsd
    + netdata now supports monitoring multiple APC UPSes.
  - isc-dhcpd
    + netdata now also supports monitoring IPv6 leases
  - fronius
    + added a new dimension solar_consumption
    + added alarms
  - stiebeleltron
    + added alarms
  - python.d
    + python.d.plugin can now start even if /etc/netdata/python.d.conf
    is missing
    + python.d.plugin now has an internal run counter
    + the unicode decoding of the plugin has been fixed
    + the plugin now does not validate self-signed certificates
    + the plugin can not revive obsolete charts
  - charts.d
    + charts.d.plugin BASH modules can now have custom number of retries in
    case of data collection failures
  * new alarm notifications plugins:
  - alerta
  - IRC
  * web server:
  - netdata now has a new internal web server that supports a fixed number
    of threads - we call it static web server. This web server allows
    netdata to work around memory fragmentation (since the treads are fixed,
    the underlying memory allocators reuse the same memory arenas) and cpu
    utilization (we can control the number of threads that will be used by
    netdata). This is the default now.
  - now the static threads web server reports the CPU usage of each of its
    threads.
  - the HTTP response headers now include the netdata version
  * dashboard:
  - the print button now respects the URL path netdata is hosted.
  - dygraphs updated to the latest version - this fixes an issue that
    prevented netdata charts from being interactive under certain conditions
  - added dygraph theme logscale
  - fontawesome updated to version 5
  - d3 updated to the latest version (this broke c3 charts that require an
    older version)
  - added d3pie charts
  - custom dashboards can now have alarms for specific roles (all, none,
    one or more).
  - allow stacked charts to zoom vertically when dimensions are selected
  - netdata now has a global XSS protection
  - netdata now uses intersectionObserver when available - this improves the
    scrolling performance of the dashboard.
  - prevent date, time and units from wrapping at the charts legends
  - various units scaling improvements
  - added data-common-colors="NAME" chart option for custom dashboards
  - added wiki page for creating custom dashboards on Atlassian's Confluence
  - prevented a double click on the charts' toolbox to select the text of
    the buttons.
  - fixed the alignment of dashboard icons
  - added a simple js, called refresh-badges.js, to update badges on a
    custom web page
  * badges:
  - netdata badges can now be scaled
  * API:
  - added gtime parameter, for group time. This is used to request from
    netdata to return values in a different rate (i.e. gtime=60 on a X/sec
    dimension, will return X/min).
  - fixed a rounding bug in JSON generation
  - the dimensions= parameter now supports simple patterns and added option
    values match-ids and match-names to control which matches are executed
    for dimensions.
  * alarms:
  - "system.swap" alarms now send notifications with a 30 seconds delay,
    to work-around a kernel bug that incorrectly reports all swap as
    instantly used under containers
  - added alarm to predict the time a mount point will run out of inodes
  - added alerta.io notifications
  - added available memory alarm
  - removed unsupported html tags from hipchat notifications.
  - pagerduty notifications have been modified to avoid incident duplication
  - alarm definitions can now use both chart IDs and chart names (prior to
    this version only chart IDs were allowed).
  - curl options (eg for disabling SSL certificates verification) for
    alarm-notify.sh can now be defined in health_alarm_notify.conf.
  - netdata can now send notifications to IRC channels
  * backends:
  - on netdata masters, allow filtering the hosts that will be sent to
    backends with send hosts matching = * pattern.
  - improved connection error handling and added retries to allow netdata
    connect to certain backends that failed with EALREADY or EINPROGRESS.
  - json backends now receive host tags (the tags have to be formatted in a
    json friendly way)
  - re-worked the alarm that triggers when backend data are lost,
    to avoid flip-flops.
  - prometheus backends:
    + added URL option timestamps=yes|no to /api/v1/allmetrics to support
    prometheus Pushgateway
    + added netdata_info variable with the version of netdata
    + renamed netdata_host_tags to netdata_host_tags_info (the old exists
    but is deprecated and will be removed eventually)
    + when prometheus uses average metrics, netdata remembers the last
    access time the prometheus collected metrics, on a per host basis.
  * metrics streaming between netdata:
  - netdata masters and proxies now expose the version of the netdata
    collecting the metrics, not their own. So, now a netdata master shows
    on the dashboard and sends to backends the version of the netdata
    collecting the metrics
  - added stream.conf option multiple "connections = accept | deny" to allow
    or deny multiple connection for the same netdata host. The default
    remains "accept", but it is likely to be changed to no on future
    versions.
  * other:
  - added global option gap when lost iterations to control the number of
    iterations that should be lost to show a gap on the charts.
  - various fixes/improvements related to netdata logs - the main change is
    that now netdata logs the thread name that logged the message, providing
    helpful insights about the thread that complained.
  - re-worked the exit procedure of netdata to allow it cleanup properly -
    sometimes netdata was deadlocked during exit, waiting forever - now
    netdata always exits promptly
  - fixed compilation on ancient gcc versions
  - netdata was always setting itself to the idle process scheduling
    priority, even when it was configured to do otherwise. Fixed it.
* Sun Dec 17 2017 9@cirno.systems
- Update to v1.9.0
  * new features:
  - IP address ACLs
  - auto-scaling units (KB → MB → GB → TB etc.)
  - dashboard snapshots for any timeframe/resolution
  - detection of TCP overflows and dropped connections
  - detection of redis background save failures
  - export dashboards to PDF
  - flock.com and kavenegar.com alarm notifications
  - highlighting timeframes on all charts by holding Ctrl or Alt
  - monitoring of couchdb, powerdns, beanstalkd and dnsdist
  - monitoring of libvirt VMs
  - new alarms:
    1. too many tcp orphan sockets
    2. tcp memory that detects that the tcp stack is under memory pressure
    or close to giving memory errors
    3. too many tcp connections (for kernels that do not support dynamic
    allocation of connections)
  - timezone support
  - unit conversion (temperatures, time, etc.)
  * fixes/improvements:
  - better/faster dashboard scrolling
  - python.d.plugin rewritten
    + supports option autodetection_retry: SECONDS
    + the new URL service disables certificates checks by default,
    to allow self-signed certificates to work without configuration.
  - streaming:
    + netdata proxies with more than 100 slaves had a timing issue that
    caused them to crash randomly on slave reconnects. Parts of the code
    have been rewritten to get rid of the timing issue.
    + netdata slaves and proxies now have a protection that ensures they will
    never use 100%% CPU, even if the master is misbehaving.
    + expired orphaned hosts are now removed from the my-netdata menu of the
    dashboard.
    + streaming functions can now be monitored via access.log
    + streaming now transfers alarm variables too
  - web_log plugin
    + custom regex now supports parsing hostnames and IPs
    + now parses lines with error 408 (request timeout - these are a special
    case, since the request has not received by the web server, so the log
    line is incomplete)
    + now properly parses resp_length with value
  - disks under Linux are renamed using /dev/disk/by-label. An option has been
    added at netdata.conf to also allow renaming based on /dev/disk/by-id.
  - chrony is now disabled by default, because there have been reports that
    chronyc enters an infinite loop in CentOS and RHEL.
  - tomcat improvements to support flavors of the tomcat server
  - chart system.io (the total system Disk I/O) is now calculated by
    aggregating the reads and writes of all physical disks. The previous
    system.io chart (that is based on pgpgin and pgpgout from /proc/vmstat)
    is now named system.pgpgio. The key difference is that the new system.io
    now sees ZFS I/O, and it also correctly and accurately sums the real disk
    bandwidth of RAID arrays.
  - chart system.net (the total system network bandwidth) is now calculated
    by aggregating the bandwidth of all physical network interfaces and is
    common for both IPv4 and IPv6.
  - tc (QoS) charts now sort the dimensions on the legends, the same way tc
    reports them.
  - mysql (and mariadb) got new charts for galera replication
  - postgres versions <= 10 the WAL directory was named pg_xlog' and from 10
    upwards has been renamed to pg_wal
  - freeipmi.plugin got a command line option (can be given in netdata.conf)
    to ignore certain sensor IDs that are faulty.
  - minor openvpn_log, smartd, smartd_log, varnish, mdstat, dns_query_time,
    isc_dhcpd, freeradius and node.d.plugin fixes/improvements
  - netdata now supports multiple plugin directories. The setting is the same
    in netdata.conf, plugins directory = "DIRECTORY1" "DIRECTORY2" ...,
    up to 20 directories.
  - netdata now supports alarms variables. Each plugin can now define host
    global and chart local variables with static values that can be used in
    alarms' expressions.
  - dashboard:
    + hover selection of charts is now faster on all browsers
    + the dashboard is now fixed when a modal is open, preventing scrolling
    + the dashboard now uses fontawesome 5.0.1 for icons
    + chart names can now be searched with browser control-F
    + netdata now detects libvirt VM network interfaces and moves them to the
    VM section of the dashboard
    + now shows the context, resolution and plugin/module of each chart in
    tooltips
    + should now put a lot less CPU pressure on the browser when the page
    does not have focus
  - statsd:
    + metrics can now be added to statsd synthetic charts using patterns
    + dimensions added to statsd synthetic charts can automatically be renamed
    using a dictionary
    + timers and histograms now report zeros when nothing is collected
  - badges:
    + fixed a bug in netdata badges that was incorrectly matching zero values
    with the null color condition
    + added API option display_absolute to allow badges use the signed value
    for color evaluation, but present the absolute value
  - alarms/notifications:
    + warning emails sent by netdata are now a little bit more orange
    (they were a bit greenish)
    + fixed a bug in email notifications that was triggering a corrupted MIME
    match by anti-spam solutions
    + pushbullet notifications now track the devices, so that per-device
    filtering at pushbullet is possible. Also improved the formatting a bit.
    + correct priority of warnings for pushover notifications
    + alarms can now use variables like this:
    ${variable with spaces or +, -, *, / in it}
  - other:
    + access.log has been refactored to support monitoring all netdata
    operations
    + inodes monitoring is now by default disabled for mount points based on
    filesystems that do not have a maximum inode threshold (such as cephfs)
    + rabbitmq has been added to apps_groups.conf so that apps.plugin now
    monitors (cpu, memory, disk I/O, sockets, etc) rabbitmq instances
    + several email and log management apps have been added to email and logs
    targets of apps_groups.conf
    + ceph target added to apps_groups.conf to allow netdata to monitor Ceph
    + refactored several internal data collection plugins to eliminate a few
    hundreds of index lookups per second
    + netdata.conf settings that are loaded from disk, but were the same with
    the default ones, were generated commented when the server was asked to
    return its config. Now all loaded settings are generated uncommented.
    + netdata simple patterns can now extract the the wildcarded part of the
    string they match (used in statsd synthetic charts)
    + netdata simple patterns can allow escaping spaces by prefixing them
    with a backslash
- Update netdata-smartd-log-path.patch
- Remove netdata-main-return.patch (fixed upstream)
- Fix rpmlint env-script-interpreter warnings
* Sun Sep 17 2017 9@cirno.systems
- Add return statement to main function (-Wreturn-type)
  * netdata-main-return.patch
* Sun Sep 17 2017 9@cirno.systems
- Update to v1.8.0
  * fixed bugs:
  - streaming slaves consuming 100%% CPU
  - missing alarm notifications on netdata masters
  - API generating corrupted JSON
  - crashing when starting on systems without writable disks
  - python.d.plugin URLService did not support HTTP keep-alive
  - streamed charts with duplicate names
  * netdata enhancements:
  - netdata can now listen on UNIX domain sockets
  - systemd netdata.service now allows setting negative netdata
    OOM score and restarts netdata if it crashes
  * new plugins:
  - CPU thermal throttling charts
  - chrony plugin
  - Stiebel Eltron plugin to collect metrics from heat pumps and
    hot water installations from Stiebel Eltron ISG
  * improved plugins:
  - web_log bugfixes, enhancements and optimizations
    (including squid logs)
  - web_log now enables parsing HTTP/2 logs in custom_log_format
  - redis bugfixes
  - haproxy bugfixes
  - elasticsearch bugfixes and optimizations
  - rabbitmq bugfixes and optimizations
  - mdstat bugfixes
  - tomcat improvements
  - mysql improvements
  - dovecot improvements
  - postgres improvements
  - cpufreq fixed a bug that prevented accurate reporting of
    CPU frequencies.
  - cpuidle performance improvements (faster under load)
  - fail2ban bugfixes
  - SNMP plugin new uses latest net-snmp and the corrupted 64-bit
    counters encountered under certain node.js versions is fixed
  * dashboard improvements:
  - easypiecharts and gauges can now render arbitrary ranges and
    animate clockwise or counterclockwise
  - container network interfaces are now moved to the container
    section
  - containers and VMs now have summary gauges on the dashboard
  - traditionally netdata was using 1024 bits = 1 kilobit.
    It is fixed: 1000 bits = 1 kilobit.
  - netdata charts should now work on wordpress pages
  * alarms and notifications:
  - alarm-notify.sh now supports debug mode, showing the exact
    commands it runs to send notifications,
    when export NETDATA_ALARM_NOTIFY_DEBUG=1
  - alarm-notify.sh now supports setting the sender email address
    of the emails it sends
  - emails sent by alarm-notify.sh now include headers to reduce
    the possibility of them being scored as spam
  - network related alarms got new thresholds and improved badges
  - netdata now detects if the system has been suspended and
    pauses all alarms for 60 seconds on resume, to prevent false
    alarms
  - netdata alarms now support filtering based on hostname and OS
  - slack notifications now show the host that sent the alarm
  * statsd:
  - the number of fractional points supported by statsd is now
    configurable (1 to 7)
  - fixed: 95th percentile calculation on statsd histograms and
    timers was incorrectly averaging the values
  - fixed: statsd metrics with non-ASCII text were processed by
    the statsd server, but were breaking JSON data generated by
    netdata
* Thu Jul 27 2017 9@cirno.systems
- Add download_files _service
- update source tarball to match upstream copy
* Sun Jul 16 2017 9@cirno.systems
- Update to v1.7.0
  * netdata is now a fully featured statsd server
  * improved metrics streaming and replication
  * backend enhancements, including:
  - host tags and metrics filtering on the netdata side
  - rewritten prometheus support to utilize more prometheus
    features and provide more flexibility and integration options
  * now monitors ZFS, ElasticSearch, RabbitMQ, Go applications
    (via expvar), samba, squid logs (with web_log plugin).
  * improved dashboard loading times
  * custom hook support for alarms
- Update netdata-smartd-log-path.patch
* Sat Jul 15 2017 plinnell@opensuse.org
- mention patches added in last commit
  * add netdata-automake-no-dist-xz.patch
  * add netdata-logrotate-su.patch
  * add netdata-smartd-log-path.patch
* Sun Jul  9 2017 9@cirno.systems
- Adjust default smartd log path to openSUSE default
* Mon Jun 26 2017 9@cirno.systems
- Update dependencies
  * Enable more features
  * Add soft dependencies
- Build on all enabled SUSE flavors
- Improve package description
- Use upstream .service/init.d/logrotate files (virtually identical)
- Fix permissions
- Clean up %%install section (more readable)
- spec-cleaner
* Mon Apr 24 2017 jengelh@inai.de
- Do not suppress errors from user/group creation.
- Trim sensationalist wording from description.
  Replace -exec rm by just -delete.
* Fri Apr 21 2017 ndas@suse.de
- Add netdata-rpmlintrc for spec file.
- Fix url and source link.
* Thu Apr 20 2017 benedikt@g5r.eu
- Update to version 1.6.0
- Add systemd unit, init script and logrotate config from netdata git repo
* Tue Jan 24 2017 aloisio@gmx.com
- Update to version 1.5.0 (see included ChangeLog)
- Added netdata-rpmlintrc
- Spec cleanup
* Fri Jun 17 2016 nirmoy.das@suse.com
- Upgraded to 1.2.0
* Fri Apr  1 2016 nirmoy.das@suse.com
- Initial package, version: 1.0.1
